spoon.messaging.SingletonMessaging

Package spoon :: Package messaging :: Class SingletonMessaging |
[hide private]
[frames] | no frames]

# Class SingletonMessaging

source code

    object --+
             |
     Messaging --+
                 |
                SingletonMessaging

For convinience this is a singleton version of the Messaging system. This can be used when the node will only have one Messaging system throughout the life of the process. Furthermore, if this is the case you can use the function/static method decorator acceptMsg with this.

Instance Methods | [hide private]
Inherited from `Messaging`: `__init__`, `handleMessage`, `registerHandler`, `send`, `setNetwork`, `unregisterHandler` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Static Methods | [hide private]
`` | getinstance()
`` | hasinstance()

Class Variables | [hide private]
`` | singleton = `None`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### getinstance() Static Method |
None

### hasinstance() Static Method |
None

Class Variable Details | [hide private]

    ### singleton None Value:
        None